"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .networktoken import NetworkToken, NetworkTokenTypedDict
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CollectionNoCursorNetworkTokenTypedDict(TypedDict):
    items: List[NetworkTokenTypedDict]
    r"""A list of items returned for this request."""


class CollectionNoCursorNetworkToken(BaseModel):
    items: List[NetworkToken]
    r"""A list of items returned for this request."""
