"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentoption import PaymentOption, PaymentOptionTypedDict
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CollectionNoCursorPaymentOptionTypedDict(TypedDict):
    items: List[PaymentOptionTypedDict]
    r"""A list of items returned for this request."""


class CollectionNoCursorPaymentOption(BaseModel):
    items: List[PaymentOption]
    r"""A list of items returned for this request."""
