"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


PaymentMethodStatus = Union[
    Literal["processing", "buyer_approval_required", "succeeded", "failed", "paused"],
    UnrecognizedStr,
]
